from .base import TemplateEngineProtocol, TemplateProtocol

__all__ = ("TemplateEngineProtocol", "TemplateProtocol")
